summaryrefslogtreecommitdiffstats
path: root/controller-api
diff options
context:
space:
mode:
authorJon Marius Venstad <jvenstad@yahoo-inc.com>2019-05-09 12:15:51 +0200
committerJon Marius Venstad <jvenstad@yahoo-inc.com>2019-05-09 12:15:51 +0200
commite0dc5aae02bff9992abcb00a928eb38b5584c3c8 (patch)
tree78f90c5b0c9c30b5fe1e7edbaa0c8db2a55db25e /controller-api
parent473518f06c194e126933bf09a1436f2d83bd796e (diff)
Store development packages per zone
Diffstat (limited to 'controller-api')
-rw-r--r--controller-api/src/main/java/com/yahoo/vespa/hosted/controller/api/integration/deployment/ApplicationStore.java9
1 files changed, 5 insertions, 4 deletions
diff --git a/controller-api/src/main/java/com/yahoo/vespa/hosted/controller/api/integration/deployment/ApplicationStore.java b/controller-api/src/main/java/com/yahoo/vespa/hosted/controller/api/integration/deployment/ApplicationStore.java
index 426a3a17296..8bfe009677c 100644
--- a/controller-api/src/main/java/com/yahoo/vespa/hosted/controller/api/integration/deployment/ApplicationStore.java
+++ b/controller-api/src/main/java/com/yahoo/vespa/hosted/controller/api/integration/deployment/ApplicationStore.java
@@ -2,6 +2,7 @@
package com.yahoo.vespa.hosted.controller.api.integration.deployment;
import com.yahoo.config.provision.ApplicationId;
+import com.yahoo.config.provision.zone.ZoneId;
/**
* Store for the application and tester packages.
@@ -37,10 +38,10 @@ public interface ApplicationStore {
/** Removes all tester packages for the given tester. */
void removeAll(TesterId tester);
- /** Stores the given application package as the development package for the given application. */
- void putDev(ApplicationId application, byte[] applicationPackage);
+ /** Stores the given application package as the development package for the given application and zone. */
+ void putDev(ApplicationId application, ZoneId zone, byte[] applicationPackage);
- /** Returns the development package for the given application. */
- byte[] getDev(ApplicationId application);
+ /** Returns the development package for the given application and zone. */
+ byte[] getDev(ApplicationId application, ZoneId zone);
}